#tool-feedback {
  list-style-image: url("chrome://feedback/skin/beta-32.png");
  background: url(chrome://browser/skin/images/toolbarbutton-default-64.png) no-repeat !important;
  width: 64px;
  height: 64px;
}

#tool-feedback:not([disabled="true"]):hover:active,
#tool-feedback[checked="true"] {
  background: url(chrome://browser/skin/images/toolbarbutton-active-64.png) no-repeat !important;
}

#feedback-feedback-happy {
  list-style-image: url("chrome://feedback/skin/happy-32.png");
}

#feedback-feedback-sad {
  list-style-image: url("chrome://feedback/skin/sad-32.png");
}
